@@ -1,8 +1,7 @@
-from urllib.parse import urlparse
-
 import math
 from elasticsearch import Elasticsearch
 
+from politylink.elasticsearch import ELASTICSEARCH_URL
 from politylink.elasticsearch.schema import AbstractText, to_cls
 
 
@@ -15,12 +14,8 @@ class ElasticsearchClient:
     Elasticsearch client for politylink endpoint
     """
 
-    def __init__(self, url='http://localhost:9200'):
-        def to_node(url):
-            res = urlparse(url)
-            return {'host': res.hostname, 'port': res.port}
-
-        self.client = Elasticsearch(hosts=[to_node(url)])
+    def __init__(self, url=ELASTICSEARCH_URL):
+        self.client = Elasticsearch(url)
 
     def index(self, obj):
         """
